@@ -45,7 +45,7 @@ test_that("No auto generate preferred citations", {
     package = "cffr"
   )
 
-  expect_snapshot_output(cff_create(rgeos,
+  expect_snapshot(cff_create(rgeos,
     gh_keywords = FALSE,
     keys = list(references = NULL)
   ))
@@ -53,7 +53,7 @@ test_that("No auto generate preferred citations", {
   basicdate <- system.file("examples/DESCRIPTION_basicdate",
     package = "cffr"
   )
-  expect_snapshot_output(cff_create(basicdate,
+  expect_snapshot(cff_create(basicdate,
     gh_keywords = FALSE,
     keys = list(references = NULL)
   ))
@@ -68,8 +68,11 @@ test_that("Fuzzy match on cff_create", {
     # If the field is already present, it would be overridden
     tittle = "Modifying a 'cff' object"
   )
-  modobject <- cff_create(newobject, keys = newkeys)
-  expect_snapshot_output(print_snapshot(
+  expect_message(
+    modobject <- cff_create(newobject, keys = newkeys),
+    "tittle: title"
+  )
+  expect_snapshot(print_snapshot(
     "Fuzzy match on cff_create",
     modobject
   ))
